#Starting file for Synchrotron Ants
setwd("C:/RBook/")
Antsall<-read.csv("Synch2_dataset_slc_final.csv",header=TRUE)
str(Antsall)
library(ggplot2)

###########################################
########Regression approaches##############
###########################################

#####Level 1 to Level 2 analysis###########
###########################################
#First, examine the data
#The plot shows the sum of all second branch radii squared by first branch radius squared.
ggplot(Antsall, aes(x=B1r2, y=Suml2r2all, color=Species)) +
  geom_point() + geom_smooth(method=lm, se=FALSE)

#Drop the outliers
Antsall<-Antsall[-c(15, 98, 99, 100, 132, 133), ]
str(Antsall)

#Have a look again at plot
#The plot shows the sum of all second branch radii squared by first branch radius squared.
ggplot(Antsall, aes(x=B1r2, y=Suml2r2all, color=Species)) +
  geom_point() + geom_smooth(method=lm, se=FALSE)

#Now examine the slopes by OLS, then forced through origin, and then by Model II
#Include a species effect
library(lmodel2)
library(nlme)

#####################
###Da Vinci's Rule###
#Intercept forced through origin (i.e. intercept = 0,0) 
DML1L2allor<-lm(Suml2r2all~B1r2 - 1, data = Antsall)
summary(DML1L2allor)
confint(DML1L2allor)

#Model II regression
DML1L2allMII<-lmodel2(Suml2r2all~B1r2, data=Antsall, "relative", "relative", nperm=999)
DML1L2allMII

###Species as a random effect###
summary(DML1L2allor_sp<-lme(Suml2r2all~B1r2 - 1, random = ~ 1|Species, data = Antsall))
ranef(DML1L2allor_sp)

##################
###Murray's Law###
#Intercept forced through origin (i.e. intercept = 0,0)
MML1L2allor<-lm(Suml2r3all~B1r3 - 1, data = Antsall)
summary(MML1L2allor)
confint(MML1L2allor)

#Model II regression
MML1L2allMII<-lmodel2(Suml2r3all~B1r3, data=Antsall, "relative", "relative", nperm=999)
MML1L2allMII

###Species as a random effect###
summary(MML1L2allor_sp<-lme(Suml2r3all ~ B1r3 - 1, random = ~ 1|Species, data = Antsall))

#######################
###Nunome's pattern###
#Intercept forced through origin (i.e. intercept = 0,0)
RML1L2allor<-lm(Suml2radall~Branch1 - 1, data = Antsall)
summary(RML1L2allor)
confint(RML1L2allor)

#Model II regression
RML1L2allMII<-lmodel2(Suml2radall~Branch1, data=Antsall, "relative", "relative", nperm=999)
RML1L2allMII

################################
# + SPECIES AS A RANDOM EFFECT
################################
summary(RML1L2allor_sp<-lme(Suml2radall ~ Branch1 - 1, random = ~ 1|Species, data = Antsall))



###########################################
#####Level 2a to Level 3a analysis#########
###########################################
#Reload the data
Antsall<-read.csv("Synch2_dataset_slc_final.csv",header=TRUE)

#The plot shows the sum of third branch radii squared by second branch (a) squared.
ggplot(Antsall, aes(x=B2ar2, y=Suml3ar2, color=Species)) +
  geom_point() + geom_smooth(method=lm, se=FALSE)
#The plot shows the sum of third branch radii cubed by second branch (a) cubed.
ggplot(Antsall, aes(x=B2ar3, y=Suml3ar3, color=Species)) +
  geom_point() + geom_smooth(method=lm, se=FALSE)
#The plot shows the sum of third branch radii by second branch (a) radius.
ggplot(Antsall, aes(x=Branch2a, y=Suml3arad, color=Species)) +
  geom_point() + geom_smooth(method=lm, se=FALSE)

#Drop the outliers
Antsall<-Antsall[-c(19, 27, 29, 34, 81, 98, 99, 100, 132), ]
str(Antsall)

#Have a look again
#The plot shows the sum of third branch radii squared by second branch (a) squared.
ggplot(Antsall, aes(x=B2ar2, y=Suml3ar2, color=Species)) +
  geom_point() + geom_smooth(method=lm, se=FALSE)
#The plot shows the sum of third branch radii cubed by second branch (a) cubed.
ggplot(Antsall, aes(x=B2ar3, y=Suml3ar3, color=Species)) +
  geom_point() + geom_smooth(method=lm, se=FALSE)
#The plot shows the sum of third branch radii by second branch (a) radius.
ggplot(Antsall, aes(x=Branch2a, y=Suml3arad, color=Species)) +
  geom_point() + geom_smooth(method=lm, se=FALSE)


#####################
###Da Vinci's Rule###
#Intercept forced through origin (i.e. intercept = 0,0) 
DML2L3aor<-lm(Suml3ar2~B2ar2 - 1, data = Antsall)
summary(DML2L3aor)
confint(DML2L3aor)

#Model II regression
DML2L3aMII<-lmodel2(Suml3ar2~B2ar2, data=Antsall, "relative", "relative", nperm=999)
DML2L3aMII

###Species as a random effect###
summary(DML2L3aor_sp<-lme(Suml3ar2 ~ B2ar2 - 1, random = ~ 1|Species, data = Antsall, na.action = na.omit))

##################
###Murray's Law###
#Intercept forced through origin (i.e. intercept = 0,0)
MML2L3aor<-lm(Suml3ar3~B2ar3 - 1, data = Antsall)
summary(MML2L3aor)
confint(MML2L3aor)

#Model II regression
MML2L3aMII<-lmodel2(Suml3ar3~B2ar3, data=Antsall, "relative", "relative", nperm=999)
MML2L3aMII

###Species as a random effect###
summary(MML2L3aor_sp<-lme(Suml3ar3 ~ B2ar3 - 1, random = ~ 1|Species, data = Antsall, na.action = na.omit))

#######################
###Nunome's pattern###
#Intercept forced through origin (i.e. intercept = 0,0)
RML2L3aor<-lm(Suml3arad~Branch2a - 1, data = Antsall)
summary(RML2L3aor)
confint(RML2L3aor)

#Model II regression
RML2L3aMII<-lmodel2(Suml3arad~Branch2a, data=Antsall, "relative", "relative", nperm=999)
RML2L3aMII

################################
# + SPECIES AS A RANDOM EFFECT
################################
summary(MML2L3aor_sp<-lme(Suml3arad ~ Branch2a - 1, random = ~ 1|Species, data = Antsall, na.action = na.omit))



###########################################
#####Level 2b to Level 3b analysis#########
###########################################
#Reload the data for new outlier check just for branch b
Antsall<-read.csv("Synch2_dataset_slc_final.csv",header=TRUE)
str(Antsall)

#The plot shows the sum of third branch radii squared by second branch (b) squared.
ggplot(Antsall, aes(x=B2br2, y=Suml3br2, color=Species)) +
  geom_point()+ geom_smooth(method=lm, se=FALSE)
#The plot shows the sum of third branch radii cubed by second branch (b) cubed.
ggplot(Antsall, aes(x=B2br3, y=Suml3br3, color=Species)) +
  geom_point()+ geom_smooth(method=lm, se=FALSE)
#The plot shows the sum of third branch radii by second branch (b) radius.
ggplot(Antsall, aes(x=Branch2b, y=Suml3brad, color=Species)) +
  geom_point()+ geom_smooth(method=lm, se=FALSE)

#Drop the outliers
Antsall<-Antsall[-c(23, 65, 66, 70, 85, 86, 90, 98, 99, 100, 108, 109, 132), ]
str(Antsall)
#Have a look again
#The plot shows the sum of third branch radii squared by second branch (b) squared.
ggplot(Antsall, aes(x=B2br2, y=Suml3br2, color=Species)) +
  geom_point()+ geom_smooth(method=lm, se=FALSE)
#The plot shows the sum of third branch radii cubed by second branch (b) cubed.
ggplot(Antsall, aes(x=B2br3, y=Suml3br3, color=Species)) +
  geom_point()+ geom_smooth(method=lm, se=FALSE)
#The plot shows the sum of third branch radii by second branch (b) radius.
ggplot(Antsall, aes(x=Branch2b, y=Suml3brad, color=Species)) +
  geom_point()+ geom_smooth(method=lm, se=FALSE)



#####################
###Da Vinci's Rule###
#Intercept forced through origin (i.e. intercept = 0,0)
DML2L3bor<-lm(Suml3br2~B2br2 - 1, data = Antsall)
summary(DML2L3bor)
confint(DML2L3bor)

#Model II regression
DML2L3bMII<-lmodel2(Suml3br2~B2br2, data=Antsall, "relative", "relative", nperm=999)
DML2L3bMII

###Species as a random effect###
summary(DML2L3bor_sp<-lme(Suml3br2 ~ B2br2 - 1, random = ~ 1|Species, data = Antsall, na.action = na.omit))

##################
###Murray's Law###
#Intercept forced through origin (i.e. intercept = 0,0)
MML2L3bor<-lm(Suml3br3~B2br3 - 1, data = Antsall)
summary(MML2L3bor)
confint(MML2L3bor)

#Model II regression
MML2L3bMII<-lmodel2(Suml3br3~B2br3, data=Antsall, "relative", "relative", nperm=999)
MML2L3bMII

###Species as a random effect###
summary(MML2L3bor_sp<-lme(Suml3br3 ~ B2br3 - 1, random = ~ 1|Species, data = Antsall, na.action = na.omit))

#######################
###Nunome's pattern###
#Intercept forced through origin (i.e. intercept = 0,0)
RML2L3bor<-lm(Suml3brad~Branch2b - 1, data = Antsall)
summary(RML2L3bor)
confint(RML2L3bor)

#Model II regression
RML2L3bMII<-lmodel2(Suml3brad~Branch2b, data=Antsall, "relative", "relative", nperm=999)
RML2L3bMII

################################
# + SPECIES AS A RANDOM EFFECT
################################
summary(RML2L3aor_sp<-lme(Suml3brad ~ Branch2b - 1, random = ~ 1|Species, data = Antsall, na.action = na.omit)) 


#############################UNIROOT CODE - SOLVE FOR X####################################
###USES SAME DATAFRAME AS LOADED ABOVE - IF COLNAMES CHANGE CODE WILL NEED TO BE UPDATED###
#############################UNIROOT CODE - SOLVE FOR X####################################
#adds a new column to 'dat' data frame for x solved as r0^x-r1^x-r2^x...ri^x = 0 #will extend intervals as needed - starts as 0-4, tolerance can also be adjusted

Antsall<-read.csv("Synch2_dataset_slc_final.csv",header=TRUE)
Antsall<-Antsall[-c(15, 98, 99, 100, 132, 133), ]


Antsall$B1_B2_xsolve<-sapply(1:nrow(Antsall), function(x){ #first solved for each stage seperately - B1 -> B2a/b 
	uniroot(function(x, r0, rX){r0^x-sum(rX^x, na.rm=T)}, lower=0, upper=4, tol=0.0000000001, extendInt = "yes", r0= Antsall[x, "Branch1"], rX= Antsall[x, c("Branch2a", "Branch2b", "Branch2c", "Branch2dD", "Branch2e")])$root})
		
Antsall$B2a_B3_xsolve<-sapply(1:nrow(Antsall), function(x){ #B2a -> B3ai/ii 
	ifelse(is.finite(Antsall[x, "Branch2a"]) & is.finite(Antsall[x, "Branch3a"]), uniroot(function(x, r0, rX){r0^x-sum(rX^x, na.rm=T)}, lower=0, upper=4, tol=0.0000000001, extendInt = "yes", r0= Antsall[x, "Branch2a"], rX= Antsall[x, c("Branch3a", "Branch3a.1")])$root, NA)}	) 
	
Antsall$B2b_B3_xsolve<-sapply(1:nrow(Antsall), function(x){ #B2b -> B3bi/ii 
	ifelse(is.finite(Antsall[x, "Branch2b"]) & is.finite(Antsall[x, "Branch3b"]), uniroot(function(x, r0, rX){r0^x-sum(rX^x, na.rm=T)}, lower=0, upper=4, tol=0.0000000001, extendInt = "yes", r0= Antsall[x, "Branch2b"], rX= Antsall[x, c("Branch3b", "Branch3b.1")])$root, NA)}	) 
	
Antsall$B2c_B3_xsolve<-sapply(1:nrow(Antsall), function(x){ #B2c -> B3ci/ii 
	ifelse(is.finite(Antsall[x, "Branch2c"]) & is.finite(Antsall[x, "Branch3c"]), uniroot(function(x, r0, rX){r0^x-sum(rX^x, na.rm=T)}, lower=0, upper=4, tol=0.0000000001, extendInt = "yes", r0= Antsall[x, "Branch2c"], rX= Antsall[x, c("Branch3c", "Branch3c.1")])$root, NA)}	) 

Antsall$allBranch_xsolve<-sapply(1:nrow(Antsall), function(x){ #This finds common x for all branches per individual (assumes all levels follow same pattern B1-B2a/b == B2a->B3ai/ii == B2b -> B3bi/ii etc.) - makes sense to me that the relationship should remain constant but I'm not particularly well versed in ant developmental biology
	uniroot(function(x, r1, r2a, r2b, r2c, r2d, r2e, r3aI, r3aII, r3bI, r3bII, r3cI, r3cII){
		sum(c(diff(c(r1^x, sum(c(r2a^x, r2b^x, r2c^x, r2d^x, r2e^x), na.rm=T)), na.rm=T), 
		 diff(c(r2a^x, sum(c(r3aI^x, r3aII^x), na.rm=T)), na.rm=T),
		 diff(c(r2b^x, sum(c(r3bI^x, r3bII^x), na.rm=T)), na.rm=T),
		 diff(c(r2c^x, sum(c(r3cI^x, r3cII^x), na.rm=T)), na.rm=T)), na.rm=T)}, lower=0, upper=4, tol=0.0000000001, extendInt = "yes", r1= Antsall[x, "Branch1"], r2a = Antsall[x, "Branch2a"], r2b = Antsall[x, "Branch2b"], r2c = Antsall[x, "Branch2c"], r2d = Antsall[x, "Branch2dD"], r2e = Antsall[x, "Branch2e"], r3aI = Antsall[x, "Branch3a"], r3aII = Antsall[x, "Branch3a.1"], r3bI = Antsall[x, "Branch3b"], r3bII = Antsall[x, "Branch3b.1"], r3cI = Antsall[x, "Branch3c"], r3cII = Antsall[x, "Branch3c.1"])$root}) #adds a new column to 'dat' data frame for x solved as r0^x-r1^x-r2^x...ri^x = 0 #will extend intervals as needed - starts as 0-4, tolerance can also be adjusted.

Antsall$bifur <- sapply(1:nrow(Antsall), function(x){sum(!(is.na(Antsall[x, c("Branch2a", "Branch2b", "Branch2c", "Branch2dD", "Branch2e")])), na.rm=T) == 2}) #adds logical column indicating if B1 -> B2 is bifurcating or not - only one indv had > 2 branches for 2->3 (Myrmecia forficata - Queen 2- also have three branches for B1->B2)

#############################UNIROOT CODE - SOLVE FOR X####################################

write.csv(Antsall, "Synch2_dataset_slc_final_xsolve.csv")




#############################GAD PLOT CODE####################################

stacked_dat <- data.frame(b0 = factor(c(rep("B1", nrow(Antsall)), rep("B2a", nrow(Antsall)), rep("B2b", nrow(Antsall))), levels = c("B1", "B2a", "B2b")), Parent = c(Antsall$Branch1, Antsall$Branch2a, Antsall$Branch2b), Child = c(rowSums(data.frame(Antsall$Branch2a, Antsall$Branch2b, Antsall$Branch2c, Antsall$Branch2dD, Antsall$Branch2e), na.rm=T), rowSums(data.frame(Antsall$Branch3a, Antsall$Branch3a.1), na.rm=T), rowSums(data.frame(Antsall$Branch3b, Antsall$Branch3b.1), na.rm=T)))[rep(Antsall$bifur, 3), ] #stacked data for branches 1-3 - only uses bifurcating for now

require(ggplot2)
ggplot(data = stacked_dat, aes(x= Parent, y = Child, col = b0)) + geom_point() + #plots our data - only bifurcating
  geom_line(data = data.frame(x = 0:90, y = sapply(0:90, function(x){((x/2)^2)*2})), aes(x=x, y=y), col="red") + #plots perfect da vinci line - red
  geom_line(data = data.frame(x = 0:90, y = sapply(0:90, function(x){((x/2)^3)*2})), aes(x=x, y=y), col = "blue") + #plots perfect murray line - blue
  geom_line(data = data.frame(x = 0:90, y = sapply(0:90, function(x){((x/2)^1)*2})), aes(x=x, y=y), col="green") + #plots perfect nunome line - green
coord_cartesian(xlim = c(0,  85), ylim = c(0, 150))

#############################SLC ADDS SKEWNESS EVALUATION####################################
library(moments)
Askew<-Antsall<-read.csv("Synch2_dataset_slc_final_xsolve.csv",header=TRUE)
str(Askew)

Askew1<-Askew[ which(Askew$B1_B2_xsolve > 0 & Askew$B1_B2_xsolve < 4), ]
str(Askew1)
skewness(Askew1$B1_B2_xsolve)
hist(Askew1$B1_B2_xsolve)
median(Askew1$B1_B2_xsolve, na.rm="TRUE")
Askew1$LogB1_B2<-log10(Askew1$B1_B2_xsolve)
hist(Askew1$LogB1_B2)
t.test(Askew1$LogB1_B2, mu = 0)

Askew2a<-Askew[ which(Askew$B2a_B3_xsolve > 0 & Askew$B2a_B3_xsolve < 4), ]
str(Askew2a)
skewness(Askew2a$B2a_B3_xsolve)
hist(Askew2a$B2a_B3_xsolve)
median(Askew2a$B2a_B3_xsolve, na.rm="TRUE")
Askew2a$LogB2a_B3<-log10(Askew2a$B2a_B3_xsolve)
hist(Askew2a$LogB2a_B3)
t.test(Askew2a$LogB2a_B3, mu = 0)

Askew2b<-Askew[ which(Askew$B2b_B3_xsolve > 0 & Askew$B2b_B3_xsolve < 4), ]
str(Askew2b)
skewness(Askew2b$B2b_B3_xsolve)
hist(Askew2b$B2b_B3_xsolve)
median(Askew2b$B2b_B3_xsolve, na.rm="TRUE")
Askew2b$LogB2b_B3<-log10(Askew2b$B2b_B3_xsolve)
hist(Askew2b$LogB2b_B3)
t.test(Askew2b$LogB2b_B3, mu = 0)
